@@ -15,10 +15,9 @@
 #include "globals.h"
 // KDEGames
 #include <KScoreDialog>
-#include <KgThemeSelector>
-#include <KStandardGameAction>
+#include <KGameThemeSelector>
+#include <KGameStandardAction>
 // KF
-#include <kwidgetsaddons_version.h>
 #include <KStandardAction>
 #include <KToggleFullScreenAction>
 #include <KActionCollection>
@@ -93,11 +92,11 @@ MainWindow::~MainWindow()
 
 void MainWindow::setupActions()
 {
-    KStandardGameAction::gameNew(this, &MainWindow::startNewGame, actionCollection());
+    KGameStandardAction::gameNew(this, &MainWindow::startNewGame, actionCollection());
 
-    KStandardGameAction::quit(this, &MainWindow::close, actionCollection());
+    KGameStandardAction::quit(this, &MainWindow::close, actionCollection());
 
-    KStandardGameAction::highscores(this, &MainWindow::showHighscores, actionCollection());
+    KGameStandardAction::highscores(this, &MainWindow::showHighscores, actionCollection());
 
     KStandardAction::preferences(this, &MainWindow::configureSettings, actionCollection());
 
@@ -109,7 +108,7 @@ void MainWindow::setupActions()
     fullScreenAction->setShortcut(fullScreenShortcut);
     QAction *fireAction = new QAction(this);
     fireAction->setText(i18n("Fire the ball"));
-    actionCollection()->setDefaultShortcut(fireAction, Qt::Key_Space);
+    KActionCollection::setDefaultShortcut(fireAction, Qt::Key_Space);
     fireAction->setIcon(QIcon::fromTheme(QStringLiteral("kbreakout")));
     connect(fireAction, &QAction::triggered, this, &MainWindow::fire);
     connect(fireAction, &QAction::changed, canvasWidget, &CanvasWidget::updateFireShortcut);
@@ -118,20 +117,20 @@ void MainWindow::setupActions()
     if (m_cheatsEnabled) {
         QAction *cheatSkipLevelAction = new QAction(this);
         cheatSkipLevelAction->setText(i18n("Skip level"));
-        actionCollection()->setDefaultShortcut(cheatSkipLevelAction, Qt::Key_S);
+        KActionCollection::setDefaultShortcut(cheatSkipLevelAction, Qt::Key_S);
         cheatSkipLevelAction->setIcon(QIcon::fromTheme(QStringLiteral("kbreakout")));
         connect(cheatSkipLevelAction, &QAction::triggered, this, &MainWindow::cheatSkipLevel);
         actionCollection()->addAction(QStringLiteral("cheatSkipLevel"), cheatSkipLevelAction);
 
         QAction *cheatAddLifeAction = new QAction(this);
         cheatAddLifeAction->setText(i18n("Add life"));
-        actionCollection()->setDefaultShortcut(cheatAddLifeAction, Qt::Key_L);
+        KActionCollection::setDefaultShortcut(cheatAddLifeAction, Qt::Key_L);
         cheatAddLifeAction->setIcon(QIcon::fromTheme(QStringLiteral("kbreakout")));
         connect(cheatAddLifeAction, &QAction::triggered, this, &MainWindow::cheatAddLife);
         actionCollection()->addAction(QStringLiteral("cheatAddLife"), cheatAddLifeAction);
     }
 
-    pauseAction = KStandardGameAction::pause(this, &MainWindow::setGamePaused, actionCollection());
+    pauseAction = KGameStandardAction::pause(this, &MainWindow::setGamePaused, actionCollection());
     // set custom keys
     QList<QKeySequence> keys;
     keys.append(i18nc("Key (shortcut) to pause the game", "P"));
@@ -153,7 +152,7 @@ void MainWindow::configureSettings()
             Settings::self());
     dialog->setModal(true);
 
-    dialog->addPage(new KgThemeSelector(canvasWidget->getProvider()),
+    dialog->addPage(new KGameThemeSelector(canvasWidget->getProvider()),
                     i18n("Theme"), QStringLiteral("games-config-theme"));
 
     // TODO: when will the page be destroyed?
@@ -174,22 +173,14 @@ void MainWindow::showHighscores()
 
 void MainWindow::startNewGame()
 {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     int ret = KMessageBox::warningTwoActions(
-#else
-    int ret = KMessageBox::warningYesNo(
-#endif
                   this,
                   i18n("Starting a new game will end the current one!"),
                   i18n("New Game"),
                   KGuiItem(i18n("Start a New Game")),
                   KStandardGuiItem::cancel());
 
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     if (ret == KMessageBox::PrimaryAction) {
-#else
-    if (ret == KMessageBox::Yes) {
-#endif
         pauseAction->setChecked(false);
         gameEngine->start(QStringLiteral("default"));
     }
@@ -304,11 +295,7 @@ void MainWindow::handleMousePressed()
 #endif
     if (dontAsk == false) {
         // ask the user if he wants to fire on mouse click
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         int res = KMessageBox::questionTwoActions(
-#else
-        int res = KMessageBox::questionYesNo(
-#endif
                       this,
                       i18n("Do you want to fire the ball on mouse click?\n"
                            "Answering Yes will make the game steal the\n"
@@ -320,11 +307,7 @@ void MainWindow::handleMousePressed()
                       QStringLiteral("dontAskFireOnClick") // doesntAskAgainName
                   );
 
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         if (res == KMessageBox::PrimaryAction) {
-#else
-        if (res == KMessageBox::Yes) {
-#endif
             Settings::setFireOnClick(true);
             Settings::self()->save();
         }
